# INTECOMM-EDC Forms Reference
## Table of contents


<a href="#user-content-1000">**1000.**</a>
1. <a href="#user-content-clinical-review-baseline">Clinical Review: Baseline</a>
2. <a href="#user-content-vitals">Vitals</a>
3. <a href="#user-content-hiv-initial-review">Hiv Initial Review</a>
4. <a href="#user-content-diabetes-initial-review">Diabetes Initial Review</a>
5. <a href="#user-content-hypertension-initial-review">Hypertension Initial Review</a>
6. <a href="#user-content-medications">Medications</a>
7. <a href="#user-content-drug-refill-hypertension">Drug Refill: Hypertension</a>
8. <a href="#user-content-drug-refill-diabetes">Drug Refill: Diabetes</a>
9. <a href="#user-content-drug-refill-hiv">Drug Refill: Hiv</a>
10. <a href="#user-content-medication-adherence-hiv">Medication Adherence (Hiv)</a>
11. <a href="#user-content-medication-adherence-diabetes">Medication Adherence (Diabetes)</a>
12. <a href="#user-content-medication-adherence-hypertension">Medication Adherence (Hypertension)</a>
13. <a href="#user-content-other-baseline-data">Other Baseline Data</a>
14. <a href="#user-content-complications-baseline">Complications: Baseline</a>
15. <a href="#user-content-family-history-and-knowledge">Family History And Knowledge</a>
16. <a href="#user-content-overall-quality-of-life-icecap-a-v2">Overall Quality Of Life (Icecap-A V2)</a>
17. <a href="#user-content-euroqol-eq-5d-3l-instrument">Euroqol Eq-5D-3L Instrument</a>
18. <a href="#user-content-health-economics-household-head">Health Economics: Household Head</a>
19. <a href="#user-content-health-economics-patient">Health Economics: Patient</a>
20. <a href="#user-content-health-economics-assets">Health Economics: Assets</a>
21. <a href="#user-content-health-economics-property">Health Economics: Property</a>
22. <a href="#user-content-health-economics-income">Health Economics: Income</a>
23. <a href="#user-content-next-appointment">Next Appointment</a>

<a href="#user-content-1010">**1010.**</a>
1. <a href="#user-content-clinical-review">Clinical Review</a>
2. <a href="#user-content-location-update">Location Update</a>
3. <a href="#user-content-vitals-1">Vitals</a>
4. <a href="#user-content-hiv-initial-review-1">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-1">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-1">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review">Hiv Review</a>
8. <a href="#user-content-viral-load-result">Viral Load Result</a>
9. <a href="#user-content-diabetes-review">Diabetes Review</a>
10. <a href="#user-content-hypertension-review">Hypertension Review</a>
11. <a href="#user-content-medications-1">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-1">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-1">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-1">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-1">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-1">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-1">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-1">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-1">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-1">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-1">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-1">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-1">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-1">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-1">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-1">Next Appointment</a>

<a href="#user-content-1020">**1020.**</a>
1. <a href="#user-content-clinical-review-1">Clinical Review</a>
2. <a href="#user-content-location-update-1">Location Update</a>
3. <a href="#user-content-vitals-2">Vitals</a>
4. <a href="#user-content-hiv-initial-review-2">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-2">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-2">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-1">Hiv Review</a>
8. <a href="#user-content-viral-load-result-1">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-1">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-1">Hypertension Review</a>
11. <a href="#user-content-medications-2">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-2">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-2">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-2">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-2">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-2">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-2">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-1">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-2">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-2">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-2">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-2">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-2">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-2">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-2">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-2">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-2">Next Appointment</a>

<a href="#user-content-1030">**1030.**</a>
1. <a href="#user-content-clinical-review-2">Clinical Review</a>
2. <a href="#user-content-location-update-2">Location Update</a>
3. <a href="#user-content-vitals-3">Vitals</a>
4. <a href="#user-content-hiv-initial-review-3">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-3">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-3">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-2">Hiv Review</a>
8. <a href="#user-content-viral-load-result-2">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-2">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-2">Hypertension Review</a>
11. <a href="#user-content-medications-3">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-3">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-3">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-3">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-3">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-3">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-3">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-2">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-3">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-3">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-3">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-3">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-3">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-3">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-3">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-3">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-3">Next Appointment</a>

<a href="#user-content-1040">**1040.**</a>
1. <a href="#user-content-clinical-review-3">Clinical Review</a>
2. <a href="#user-content-location-update-3">Location Update</a>
3. <a href="#user-content-vitals-4">Vitals</a>
4. <a href="#user-content-hiv-initial-review-4">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-4">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-4">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-3">Hiv Review</a>
8. <a href="#user-content-viral-load-result-3">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-3">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-3">Hypertension Review</a>
11. <a href="#user-content-medications-4">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-4">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-4">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-4">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-4">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-4">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-4">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-3">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-4">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-4">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-4">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-4">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-4">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-4">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-4">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-4">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-4">Next Appointment</a>

<a href="#user-content-1050">**1050.**</a>
1. <a href="#user-content-clinical-review-4">Clinical Review</a>
2. <a href="#user-content-location-update-4">Location Update</a>
3. <a href="#user-content-vitals-5">Vitals</a>
4. <a href="#user-content-hiv-initial-review-5">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-5">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-5">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-4">Hiv Review</a>
8. <a href="#user-content-viral-load-result-4">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-4">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-4">Hypertension Review</a>
11. <a href="#user-content-medications-5">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-5">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-5">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-5">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-5">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-5">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-5">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-4">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-5">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-5">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-5">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-5">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-5">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-5">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-5">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-5">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-5">Next Appointment</a>

<a href="#user-content-1060">**1060.**</a>
1. <a href="#user-content-clinical-review-5">Clinical Review</a>
2. <a href="#user-content-location-update-5">Location Update</a>
3. <a href="#user-content-vitals-6">Vitals</a>
4. <a href="#user-content-hiv-initial-review-6">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-6">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-6">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-5">Hiv Review</a>
8. <a href="#user-content-viral-load-result-5">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-5">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-5">Hypertension Review</a>
11. <a href="#user-content-medications-6">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-6">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-6">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-6">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-6">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-6">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-6">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-5">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-6">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-6">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-6">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-6">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-6">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-6">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-6">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-6">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-6">Next Appointment</a>

<a href="#user-content-1070">**1070.**</a>
1. <a href="#user-content-clinical-review-6">Clinical Review</a>
2. <a href="#user-content-location-update-6">Location Update</a>
3. <a href="#user-content-vitals-7">Vitals</a>
4. <a href="#user-content-hiv-initial-review-7">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-7">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-7">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-6">Hiv Review</a>
8. <a href="#user-content-viral-load-result-6">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-6">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-6">Hypertension Review</a>
11. <a href="#user-content-medications-7">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-7">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-7">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-7">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-7">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-7">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-7">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-6">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-7">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-7">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-7">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-7">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-7">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-7">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-7">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-7">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-7">Next Appointment</a>

<a href="#user-content-1080">**1080.**</a>
1. <a href="#user-content-clinical-review-7">Clinical Review</a>
2. <a href="#user-content-location-update-7">Location Update</a>
3. <a href="#user-content-vitals-8">Vitals</a>
4. <a href="#user-content-hiv-initial-review-8">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-8">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-8">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-7">Hiv Review</a>
8. <a href="#user-content-viral-load-result-7">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-7">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-7">Hypertension Review</a>
11. <a href="#user-content-medications-8">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-8">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-8">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-8">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-8">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-8">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-8">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-7">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-8">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-8">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-8">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-8">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-8">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-8">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-8">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-8">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-8">Next Appointment</a>

<a href="#user-content-1090">**1090.**</a>
1. <a href="#user-content-clinical-review-8">Clinical Review</a>
2. <a href="#user-content-location-update-8">Location Update</a>
3. <a href="#user-content-vitals-9">Vitals</a>
4. <a href="#user-content-hiv-initial-review-9">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-9">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-9">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-8">Hiv Review</a>
8. <a href="#user-content-viral-load-result-8">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-8">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-8">Hypertension Review</a>
11. <a href="#user-content-medications-9">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-9">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-9">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-9">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-9">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-9">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-9">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-8">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-9">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-9">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-9">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-9">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-9">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-9">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-9">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-9">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-9">Next Appointment</a>

<a href="#user-content-1100">**1100.**</a>
1. <a href="#user-content-clinical-review-9">Clinical Review</a>
2. <a href="#user-content-location-update-9">Location Update</a>
3. <a href="#user-content-vitals-10">Vitals</a>
4. <a href="#user-content-hiv-initial-review-10">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-10">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-10">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-9">Hiv Review</a>
8. <a href="#user-content-viral-load-result-9">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-9">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-9">Hypertension Review</a>
11. <a href="#user-content-medications-10">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-10">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-10">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-10">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-10">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-10">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-10">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-9">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-10">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-10">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-10">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-10">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-10">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-10">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-10">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-10">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-10">Next Appointment</a>

<a href="#user-content-1110">**1110.**</a>
1. <a href="#user-content-clinical-review-10">Clinical Review</a>
2. <a href="#user-content-location-update-10">Location Update</a>
3. <a href="#user-content-vitals-11">Vitals</a>
4. <a href="#user-content-hiv-initial-review-11">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-11">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-11">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-10">Hiv Review</a>
8. <a href="#user-content-viral-load-result-10">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-10">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-10">Hypertension Review</a>
11. <a href="#user-content-medications-11">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-11">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-11">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-11">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-11">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-11">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-11">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-10">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-11">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-11">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-11">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-11">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-11">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-11">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-11">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-11">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-11">Next Appointment</a>

<a href="#user-content-1120">**1120.**</a>
1. <a href="#user-content-clinical-review-11">Clinical Review</a>
2. <a href="#user-content-location-update-11">Location Update</a>
3. <a href="#user-content-vitals-12">Vitals</a>
4. <a href="#user-content-hiv-initial-review-12">Hiv Initial Review</a>
5. <a href="#user-content-diabetes-initial-review-12">Diabetes Initial Review</a>
6. <a href="#user-content-hypertension-initial-review-12">Hypertension Initial Review</a>
7. <a href="#user-content-hiv-review-11">Hiv Review</a>
8. <a href="#user-content-viral-load-result-11">Viral Load Result</a>
9. <a href="#user-content-diabetes-review-11">Diabetes Review</a>
10. <a href="#user-content-hypertension-review-11">Hypertension Review</a>
11. <a href="#user-content-medications-12">Medications</a>
12. <a href="#user-content-drug-refill-hypertension-12">Drug Refill: Hypertension</a>
13. <a href="#user-content-drug-refill-diabetes-12">Drug Refill: Diabetes</a>
14. <a href="#user-content-drug-refill-hiv-12">Drug Refill: Hiv</a>
15. <a href="#user-content-medication-adherence-hiv-12">Medication Adherence (Hiv)</a>
16. <a href="#user-content-medication-adherence-diabetes-12">Medication Adherence (Diabetes)</a>
17. <a href="#user-content-medication-adherence-hypertension-12">Medication Adherence (Hypertension)</a>
18. <a href="#user-content-complications-followup-11">Complications: Followup</a>
19. <a href="#user-content-family-history-and-knowledge-12">Family History And Knowledge</a>
20. <a href="#user-content-overall-quality-of-life-icecap-a-v2-12">Overall Quality Of Life (Icecap-A V2)</a>
21. <a href="#user-content-euroqol-eq-5d-3l-instrument-12">Euroqol Eq-5D-3L Instrument</a>
22. <a href="#user-content-health-economics-household-head-12">Health Economics: Household Head</a>
23. <a href="#user-content-health-economics-patient-12">Health Economics: Patient</a>
24. <a href="#user-content-health-economics-assets-12">Health Economics: Assets</a>
25. <a href="#user-content-health-economics-property-12">Health Economics: Property</a>
26. <a href="#user-content-health-economics-income-12">Health Economics: Income</a>
27. <a href="#user-content-next-appointment-12">Next Appointment</a>


### 1000

#### Clinical Review: Baseline
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreviewbaseline
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreviewbaseline
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Has the patient ever tested <U>positive</U> for HIV infection?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** Was a diagnosis of HIV reported at screening?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: hiv_dx_at_screening
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Diabetes**

**5.0.** Has the patient ever been diagnosed with DIABETES?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Was a diagnosis of DIABETES reported at screening?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: dm_dx_at_screening
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Hypertension**

**7.0.** Has the patient ever been diagnosed with HYPERTENSION?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** Was a diagnosis of HYPERTENSION reported at screening?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: htn_dx_at_screening
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**9.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Protocol incident**

**11.0.** Do any of the above diagnosis differ from those reported at screening?
- db_table: intecomm_subject_clinicalreviewbaseline
- column: protocol_incident
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**12.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreviewbaseline
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**13.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreviewbaseline
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Other Baseline Data
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_otherbaselinedata
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_otherbaselinedata
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Smoking**

**3.0.** Which of these options describes you?
- db_table: intecomm_subject_otherbaselinedata
- column: smoking_status
- type: CharField
- length: 15
- responses:
  - `smoker`: *Currently smoke*
  - `former_smoker`: *Used to smoke but stopped*
  - `nonsmoker`: *Never smoked*
---

**4.0.** If you used to smoke but stopped, how long ago did you stop?

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_otherbaselinedata
- column: smoker_quit_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** If you are still smoking, how long have you been smoking?

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_otherbaselinedata
- column: smoker_duration
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Alcohol**

**6.0.** Do you drink alcohol?
- db_table: intecomm_subject_otherbaselinedata
- column: alcohol
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**7.0.** If yes, how often do you drink alcohol?
- db_table: intecomm_subject_otherbaselinedata
- column: alcohol_consumption
- type: CharField
- length: 25
- responses:
  - `occasionally`: *Occasionally*
  - `1_2_per_week`: *1-2 times a week*
  - `3_4_per_week`: *3-4 times a week*
  - `daily`: *Daily*
  - `N/A`: *Not applicable*
---

**Section: Diet**

**8.0.** On average, how many green leafy vegetables do you eat in a day?

&nbsp;&nbsp;&nbsp;&nbsp; *Number per day*
- db_table: intecomm_subject_otherbaselinedata
- column: num_leafy_vegs_eaten
- type: IntegerField
---

**8.1.** On average, how many other vegetables do you eat in a day?

&nbsp;&nbsp;&nbsp;&nbsp; *Other vegetables like carrots, tomatoes, bell papers etc. Number per day*
- db_table: intecomm_subject_otherbaselinedata
- column: num_other_vegs_eaten
- type: IntegerField
---

**9.0.** On average, how many vegetables do you eat in a day?

&nbsp;&nbsp;&nbsp;&nbsp; *Number per day*
- db_table: intecomm_subject_otherbaselinedata
- column: num_fruits_eaten
- type: IntegerField
---

**10.0.** Do you add salt to your food in addition to what has been added when cooking?
- db_table: intecomm_subject_otherbaselinedata
- column: adds_salt_to_food
- type: CharField
- length: 15
- responses:
  - `always`: *Always*
  - `very_often`: *Very Often*
  - `sometimes`: *Sometimes*
  - `rarely`: *Rarely*
  - `NEVER`: *Never*
---

**Section: Physical activity: Work**

**11.0.** Does your work involve moderate or vigorous-intensity physical activity?

&nbsp;&nbsp;&nbsp;&nbsp; *See interviewer notes above.*
- db_table: intecomm_subject_otherbaselinedata
- column: activity_work
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, how many DAYS do you do these physical activities as part of your work? (in a typical week)

&nbsp;&nbsp;&nbsp;&nbsp; *Number of days in a typical week*
- db_table: intecomm_subject_otherbaselinedata
- column: activity_work_days_per_wk
- type: IntegerField
---

**Section: Physical activity: Personal**

**13.0.** How many DAYS do you do personal exercise, sports or fitness activities? (in a typical week)

&nbsp;&nbsp;&nbsp;&nbsp; *Number of days in a typical week*
- db_table: intecomm_subject_otherbaselinedata
- column: activity_exercise_days_per_wk
- type: IntegerField
---

**Section: Physical activity: Average per day**

**14.0.** On an average day, how many MINUTES do you spend on all physical activities combined? (moderate or vigorous-intensity work activities, exercise, sports and fitness)

&nbsp;&nbsp;&nbsp;&nbsp; *Number of minutes in a typical day*
- db_table: intecomm_subject_otherbaselinedata
- column: activity_combined_mn_avg_day
- type: IntegerField
---

**Section: Employment**

**15.0.** What is the patient's employment status?
- db_table: intecomm_subject_otherbaselinedata
- column: employment_status
- type: CharField
- length: 25
- responses:
  - `professional`: *Professional / office work / business*
  - `manual_work`: *Skilled / Unskilled manual work*
  - `housewife`: *Housewife*
  - `unemployed`: *Not working / seeking work*
  - `unemployed_not_seeking`: *Not working / NOT seeking work*
  - `retired`: *Retired*
  - `OTHER`: *Other, please specify*
---

**15.1.** If other, please specify ...
- db_table: intecomm_subject_otherbaselinedata
- column: employment_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Education**

**16.0.** How much formal education does the patient have?
- db_table: intecomm_subject_otherbaselinedata
- column: education
- type: CharField
- length: 25
- responses:
  - `no_formal_education`: *No Formal Education*
  - `primary`: *Up to primary*
  - `secondary`: *Up to secondary / high school*
  - `post_secondary`: *College or similar higher institution*
  - `tertiary`: *university educated*
---

**Section: Marital Status**

**17.0.** Personal status?
- db_table: intecomm_subject_otherbaselinedata
- column: marital_status
- type: CharField
- length: 25
- responses:
  - `married`: *Married or living with someone*
  - `single`: *Single*
  - `divorced`: *Divorced*
  - `widowed`: *Widow / Spinster*
---

**Section: CRF status**

**18.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_otherbaselinedata
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**19.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_otherbaselinedata
- column: crf_status_comments
- type: TextField
---


#### Complications: Baseline
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsbaseline
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsbaseline
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsbaseline
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, how long ago

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_complicationsbaseline
- column: stroke_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsbaseline
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, how long ago

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_complicationsbaseline
- column: heart_attack_ago
- type: CharField
- length: 8
- responses: *free text*
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsbaseline
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, how long ago

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_complicationsbaseline
- column: renal_disease_ago
- type: CharField
- length: 8
- responses: *free text*
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsbaseline
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, how long ago

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_complicationsbaseline
- column: vision_ago
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsbaseline
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, how long ago

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_complicationsbaseline
- column: numbness_ago
- type: CharField
- length: 8
- responses: *free text*
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsbaseline
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, how long ago

&nbsp;&nbsp;&nbsp;&nbsp; * Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_complicationsbaseline
- column: foot_ulcers_ago
- type: CharField
- length: 8
- responses: *free text*
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsbaseline
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsbaseline
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsbaseline
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsbaseline
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1010

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1020

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1030

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1040

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1050

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1060

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1070

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1080

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1090

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1100

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1110

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions

### 1120

#### Clinical Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_clinicalreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_clinicalreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: HIV**

**3.0.** Since last seen, was the patient tested for HIV infection?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: hiv_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: hiv_test_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Why was the patient tested for HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: hiv_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** As of today, was the patient <u>newly</u> diagnosed with HIV infection?
- db_table: intecomm_subject_clinicalreview
- column: hiv_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Diabetes**

**7.0.** Since last seen, was the patient tested for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: dm_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: dm_test_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Why was the patient tested for diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**9.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: dm_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** As of today, was the patient <u>newly</u> diagnosed with diabetes?
- db_table: intecomm_subject_clinicalreview
- column: dm_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Hypertension**

**11.0.** Since last seen, was the patient tested for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.*
- db_table: intecomm_subject_clinicalreview
- column: htn_test
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** Date test requested
- db_table: intecomm_subject_clinicalreview
- column: htn_test_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Why was the patient tested for hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `patient_request`: *Patient was well and made a request*
  - `patient_complication`: *Patient had a clinical complication*
  - `signs_symptoms`: *Patient had suggestive signs and symptoms*
  - `OTHER`: *Other reason (specify below)*
---

**13.1.** If other, please specify ...
- db_table: intecomm_subject_clinicalreview
- column: htn_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**14.0.** As of today, was the patient <u>newly</u> diagnosed with hypertension?
- db_table: intecomm_subject_clinicalreview
- column: htn_dx
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Complications**

**15.0.** Since last seen, has the patient had any complications

&nbsp;&nbsp;&nbsp;&nbsp; *If Yes, complete the `Complications` CRF*
- db_table: intecomm_subject_clinicalreview
- column: complications
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: Other**

**16.0.** Does the patient have any private or work-place health insurance?
- db_table: intecomm_subject_clinicalreview
- column: health_insurance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**17.0.** In the last month, how much has the patient spent on health insurance

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: health_insurance_monthly_pay
- type: IntegerField
---

**18.0.** Does the patient belong to a ‘club’ that supports medicines purchase?
- db_table: intecomm_subject_clinicalreview
- column: patient_club
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**19.0.** In the last month, how much has the patient spent on club membership

&nbsp;&nbsp;&nbsp;&nbsp; *amount in local currency*
- db_table: intecomm_subject_clinicalreview
- column: patient_club_monthly_pay
- type: IntegerField
---

**Section: CRF status**

**20.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_clinicalreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**21.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_clinicalreview
- column: crf_status_comments
- type: TextField
---


#### Location Update
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_locationupdate
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_locationupdate
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Update**

**3.0.** Where is this visit taking place
- db_table: intecomm_subject_locationupdate
- column: location
- type: CharField
- length: 100
- responses:
  - `community`: *In the community*
  - `clinic`: *At the facility*
  - `OTHER`: *Other, specify below ...*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_locationupdate
- column: location_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** Briefly explain why the participant is not at the location expected based on their randomization

&nbsp;&nbsp;&nbsp;&nbsp; * (Encryption: AES local)*
- db_table: intecomm_subject_locationupdate
- column: comments
- type: CharField
- length: 71
- responses: *free text*
---

**5.0.** Is the participant expected to attend their next visit at the location they were randomized to
- db_table: intecomm_subject_locationupdate
- column: next_location
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_locationupdate
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_locationupdate
- column: crf_status_comments
- type: TextField
---


#### Vitals
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: To be completed by the research nurse.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_vitals
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_vitals
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Weight, Height and Temperature**

**3.0.** Is weight estimated or measured?
- db_table: intecomm_subject_vitals
- column: weight_determination
- type: CharField
- length: 15
- responses:
  - `measured`: *Measured*
  - `estimated`: *Estimated*
  - `N/A`: *Not recorded / Not applicable*
---

**4.0.** Weight:

&nbsp;&nbsp;&nbsp;&nbsp; *in kg*
- db_table: intecomm_subject_vitals
- column: weight
- type: DecimalField
---

**5.0.** Height:

&nbsp;&nbsp;&nbsp;&nbsp; *in centimeters*
- db_table: intecomm_subject_vitals
- column: height
- type: DecimalField
---

**6.0.** Temperature:

&nbsp;&nbsp;&nbsp;&nbsp; *in degrees Celsius*
- db_table: intecomm_subject_vitals
- column: temperature
- type: DecimalField
---

**Section: Blood Pressure: First reading**

**7.0.** Was the first blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_one_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_one_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**9.0.** Blood pressure: systolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_one
- type: IntegerField
---

**10.0.** Blood pressure: diastolic (first reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_one
- type: IntegerField
---

**Section: Blood Pressure: Second reading**

**11.0.** Was the second blood pressure reading done
- db_table: intecomm_subject_vitals
- column: bp_two_taken
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**12.0.** If not done, please explain
- db_table: intecomm_subject_vitals
- column: bp_two_not_taken_reason
- type: CharField
- length: 50
- responses: *free text*
---

**13.0.** Blood pressure: systolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in mm. format SYS, e.g. 120*
- db_table: intecomm_subject_vitals
- column: sys_blood_pressure_two
- type: IntegerField
---

**14.0.** Blood pressure: diastolic (second reading)

&nbsp;&nbsp;&nbsp;&nbsp; *in Hg. format DIA, e.g. 80*
- db_table: intecomm_subject_vitals
- column: dia_blood_pressure_two
- type: IntegerField
---

**Section: Severe hypertension**

**15.0.** Does the patient have severe hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *Based on the above readings. Severe HTN is any BP reading > 180/110mmHg*
- db_table: intecomm_subject_vitals
- column: severe_htn
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: Comments**

**16.0.** comments
- db_table: intecomm_subject_vitals
- column: comments
- type: TextField
---

**Section: CRF Status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_vitals
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_vitals
- column: crf_status_comments
- type: TextField
---


#### Hiv Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivinitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivinitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis and Care**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Is the patient receiving care for HIV?
- db_table: intecomm_subject_hivinitialreview
- column: receives_care
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Where does the patient receive care for HIV
- db_table: intecomm_subject_hivinitialreview
- column: clinic
- type: CharField
- length: 15
- responses:
  - `this_clinic`: *Patient comes to this facility for their care*
  - `OTHER`: *Patient goes to a different clinic*
  - `N/A`: *Not applicable*
---

**6.1.** If not attending here, where does the patient attend?
- db_table: intecomm_subject_hivinitialreview
- column: clinic_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Monitoring and Treatment**

**7.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivinitialreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**8.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivinitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**10.0.** Is the patient's most recent viral load result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_vl
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `PENDING`: *Pending*
  - `N/A`: *Not applicable*
---

**11.0.** Date specimen drawn

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, please estimate*
- db_table: intecomm_subject_hivinitialreview
- column: drawn_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Most recent viral load

&nbsp;&nbsp;&nbsp;&nbsp; *copies/mL*
- db_table: intecomm_subject_hivinitialreview
- column: vl
- type: IntegerField
---

**13.0.** vl quantifier
- db_table: intecomm_subject_hivinitialreview
- column: vl_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `<`: *<*
  - `N/A`: *Not applicable*
---

**14.0.** Is the patient's most recent CD4 result available?
- db_table: intecomm_subject_hivinitialreview
- column: has_cd4
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**15.0.** Most recent CD4

&nbsp;&nbsp;&nbsp;&nbsp; *cells/mm<sup>3</sup>*
- db_table: intecomm_subject_hivinitialreview
- column: cd4
- type: IntegerField
---

**16.0.** Date of most recent CD4
- db_table: intecomm_subject_hivinitialreview
- column: cd4_date
- type: DateField
- format: YYYY-MM-DD
---

**Section: CRF status**

**17.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**18.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivinitialreview
- column: crf_status_comments
- type: TextField
---


#### Diabetes Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dminitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dminitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Treatment**

**5.0.** How is the patient's diabetes managed?
- db_table: intecomm_subject_dminitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `insulin`: *Insulin injections*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_dminitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for diabetes

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for diabetes?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_dminitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Blood Glucose Measurement**

**8.0.** Has the patient had their glucose measured in the last few months?
- db_table: intecomm_subject_dminitialreview
- column: glucose_performed
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**9.0.** Was glucose measured while fasting?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**10.0.** How long did they fast (in hours and minutes)?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dminitialreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**11.0.** Glucose date measured
- db_table: intecomm_subject_dminitialreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**12.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dminitialreview
- column: glucose_value
- type: DecimalField
---

**13.0.** Glucose quantifier
- db_table: intecomm_subject_dminitialreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**14.0.** Glucose units
- db_table: intecomm_subject_dminitialreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**15.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dminitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**16.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dminitialreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Initial Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htninitialreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htninitialreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Hypertension diagnosis**

**3.0.** Date patient diagnosed

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: dx_date
- type: DateField
- format: YYYY-MM-DD
---

**4.0.** If date not known, how long ago was the patient diagnosed?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: dx_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: Hypertension treatment**

**5.0.** How is the patient's hypertension managed?
- db_table: intecomm_subject_htninitialreview
- column: managed_by
- type: ManyToManyField
- responses: *Select all that apply*
  - `drugs`: *Oral drugs*
  - `diet_lifestyle`: *Diet and lifestyle*
  - `OTHER`: *Other, please specify below ...*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_htninitialreview
- column: managed_by_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** Date started medicines for hypertension

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** If date not known, how long ago did the patient start medicines for hypertension?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_htninitialreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htninitialreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htninitialreview
- column: crf_status_comments
- type: TextField
---


#### Hiv Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_hivreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**3.1.** If other facility, please specify
- db_table: intecomm_subject_hivreview
- column: care_delivery_other
- type: TextField
---

**Section: Anit-retroviral therapy (ART)**

**4.0.** Has the patient started antiretroviral therapy (ART)?
- db_table: intecomm_subject_hivreview
- column: rx_init
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Date started antiretroviral therapy (ART)

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date here instead of estimating.*
- db_table: intecomm_subject_hivreview
- column: rx_init_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** If date not known, how long ago did the patient start antiretroviral therapy (ART)?

&nbsp;&nbsp;&nbsp;&nbsp; *If possible, provide the exact date above instead of estimating here. Format is `YYyMMm` or `DDd`. For example 3y10m, 12y7m ... or 7d, 0d ...*
- db_table: intecomm_subject_hivreview
- column: rx_init_ago
- type: CharField
- length: 8
- responses: *free text*
---

**Section: CRF status**

**7.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**8.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivreview
- column: crf_status_comments
- type: TextField
---


#### Viral Load Result
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_viralloadresult
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_viralloadresult
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Requisition and Result Date**

**3.0.** Requisition

&nbsp;&nbsp;&nbsp;&nbsp; *Start typing the requisition identifier or select one from this visit*
- db_table: intecomm_subject_viralloadresult
- column: requisition
- type: ForeignKey
---

**4.0.** Result assay date and time
- db_table: intecomm_subject_viralloadresult
- column: assay_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: VL**

**5.0.** VL Result

&nbsp;&nbsp;&nbsp;&nbsp; *in copies/mL*
- db_table: intecomm_subject_viralloadresult
- column: vl_value
- type: IntegerField
---


#### Diabetes Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Blood Sugar Measurement**

**3.0.** Has the participant fasted?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** How long have they fasted in hours and/or minutes?

&nbsp;&nbsp;&nbsp;&nbsp; *As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc*
- db_table: intecomm_subject_dmreview
- column: glucose_fasting_duration_str
- type: CharField
- length: 8
- responses: *free text*
---

**5.0.** Glucose date measured
- db_table: intecomm_subject_dmreview
- column: glucose_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Glucose level

&nbsp;&nbsp;&nbsp;&nbsp; *A `HIGH` reading may be entered as 9999.99*
- db_table: intecomm_subject_dmreview
- column: glucose_value
- type: DecimalField
---

**7.0.** Glucose quantifier
- db_table: intecomm_subject_dmreview
- column: glucose_quantifier
- type: CharField
- length: 10
- responses:
  - `=`: *=*
  - `>`: *>*
  - `>=`: *>=*
  - `<`: *<*
  - `<=`: *<=*
  - `N/A`: *Not applicable*
---

**8.0.** Glucose units
- db_table: intecomm_subject_dmreview
- column: glucose_units
- type: CharField
- length: 15
- responses:
  - `mg/dL`: *mg/dL*
  - `mmol/L`: *mmol/L (millimoles/L)*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**9.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**10.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmreview
- column: crf_status_comments
- type: TextField
---


#### Hypertension Review
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnreview
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnreview
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Care**

**3.0.** How will the patient's hypertension be managed going forward?
- db_table: intecomm_subject_htnreview
- column: managed_by
- type: CharField
- length: 25
- responses:
  - `drugs`: *Drugs / Medicine*
  - `diet_lifestyle`: *Diet and lifestyle alone*
---

**4.0.** Care for this `condition` was delivered today at ...
- db_table: intecomm_subject_htnreview
- column: care_delivery
- type: CharField
- length: 25
- responses:
  - `health_facility`: *Health facility*
  - `community_clinic`: *Community clinic*
  - `OTHER`: *Other facility, please specify below ...*
  - `N/A`: *Not applicable*
---

**4.1.** If other facility, please specify
- db_table: intecomm_subject_htnreview
- column: care_delivery_other
- type: TextField
---

**Section: CRF status**

**5.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnreview
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**6.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnreview
- column: crf_status_comments
- type: TextField
---


#### Medications
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_medications
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_medications
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Prescriptions**

**3.0.** Is the patient filling / refilling HIV medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for HIV infection.*
- db_table: intecomm_subject_medications
- column: refill_hiv
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**4.0.** Is the patient filling / refilling Diabetes medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Diabetes.*
- db_table: intecomm_subject_medications
- column: refill_dm
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**5.0.** Is the patient filling / refilling Hypertension medications?

&nbsp;&nbsp;&nbsp;&nbsp; *Select `not applicable` if subject has not been diagnosed and prescribed medication for Hypertension.*
- db_table: intecomm_subject_medications
- column: refill_htn
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `N/A`: *Not applicable*
---

**Section: CRF status**

**6.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_medications
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**7.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_medications
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hypertension
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhtn
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhtn
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhtn
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `aldactone`: *Aldactone (Spironolactone)*
  - `amlodipine`: *Amlodipine*
  - `atenolol`: *Atenolol*
  - `atorvastatin`: *Atorvastatin*
  - `bendroflumethiazide`: *Bendroflumethiazide*
  - `bisoprolol`: *Bisoprolol*
  - `candesartan`: *Candesartan*
  - `captopril`: *Captopril*
  - `carvedilol`: *Carvedilol*
  - `clopidogrel`: *Clopidogrel*
  - `enalapril`: *Enalapril*
  - `frusemide`: *Frusemide*
  - `hydralazine`: *Hydralazine*
  - `hydrochlorothiazide`: *Hydrochlorothiazide*
  - `irbesartan`: *Irbesartan*
  - `irbesartan_hydrochlorothiazide`: *Irbesartan Hydrochlorothiazide*
  - `junior_aspirin`: *Junior Aspirin*
  - `lisinopril`: *Lisinopril*
  - `losartan_h`: *losartan Hydrochlorothiazide (Losartan H/Repace H)*
  - `losartan`: *losartan*
  - `methyldopa`: *Methyldopa*
  - `metoprolol`: *Metoprolol*
  - `nifedipine`: *Nifedipine*
  - `olmesartan`: *Olmesartan*
  - `propanolol`: *Propanolol*
  - `ramipril`: *Ramipril*
  - `rosuvastatin`: *Rosuvastatin*
  - `s-amlodipine`: *S-Amlodipine*
  - `simvastatin`: *Simvastatin*
  - `telmisartan`: *Telmisartan*
  - `valsartan`: *Valsartan*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid*
  - `OTHER`: *Other treatment (specify below)*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhtn
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhtn
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhtn
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Diabetes
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefilldm
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefilldm
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefilldm
- column: rx
- type: ManyToManyField
- responses: *Select all that apply*
  - `glibenclamide_metformin`: *Glibenclamide + Metformin combo*
  - `glibenclamide_s`: *Glibenclamide (S)*
  - `gliclazide_s`: *Gliclazide (S)*
  - `glimepiride_1mg_metformin`: *Glimepiride (1mg) + Metformin combo*
  - `glimepiride_2mg_metformin`: *Glimepiride (2mg) + Metformin combo*
  - `glimepiride_s`: *Glimepiride (S)*
  - `glipizide_s`: *Glipizide (S)*
  - `insulin`: *Insulin*
  - `metformin_b`: *Metformin (B)*
  - `pioglitazone`: *Pioglitazone*
  - `pregabalin`: *Pregabalin (diabetic neuropathy)*
  - `vitamin_b_folic_acid`: *Vitamin Bs + Folic Acid (Neuroton- diabetic neuropathy)*
  - `OTHER`: *Other, specify*
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefilldm
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefilldm
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefilldm
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefilldm
- column: rx_days
- type: IntegerField
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefilldm
- column: crf_status_comments
- type: TextField
---


#### Drug Refill: Hiv
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <span style="color:orange">Note: Medications CRF must be completed first.</span>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_drugrefillhiv
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_drugrefillhiv
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Refill Information**

**3.0.** Which medicine did the patient receive today?
- db_table: intecomm_subject_drugrefillhiv
- column: rx
- type: ForeignKey
---

**3.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: rx_other
- type: CharField
- length: 150
- responses: *free text*
---

**4.0.** Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_modified
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**5.0.** Which changes occurred?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications
- type: ManyToManyField
- responses: *Select all that apply*
  - `dose_changes`: *Dose changes*
  - `drugs_substitution`: *Drugs substitution*
  - `drug_additions`: *Additional drugs added to existing regimen*
  - `some_stopped`: *Some drugs stopped*
  - `OTHER`: *Other, specify*
---

**5.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_other
- type: CharField
- length: 150
- responses: *free text*
---

**6.0.** Why did the patient’s previous prescription change?
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `availability`: *Limited availability of drugs*
  - `side_effects`: *Had side-effects*
  - `feel_better`: *Felt well and stopped/reduced drug prescription*
  - `OTHER`: *Other, specify*
---

**6.1.** If other, please specify ...
- db_table: intecomm_subject_drugrefillhiv
- column: modifications_reason_other
- type: CharField
- length: 150
- responses: *free text*
---

**Section: Drug Supply: HIV**

**7.0.** Number of days of medication prescribed?
- db_table: intecomm_subject_drugrefillhiv
- column: rx_days
- type: IntegerField
---

**8.0.** How many days supplied by the clinic

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: clinic_days
- type: IntegerField
---

**9.0.** How many days supplied by a club

&nbsp;&nbsp;&nbsp;&nbsp; *days*
- db_table: intecomm_subject_drugrefillhiv
- column: club_days
- type: IntegerField
---

**10.0.** How many days supplied by to be purchased

&nbsp;&nbsp;&nbsp;&nbsp; *This can be purchased by patient, through a medicines club that the patient belong to, through insurance or someone else has paid. *
- db_table: intecomm_subject_drugrefillhiv
- column: purchased_days
- type: IntegerField
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_drugrefillhiv
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hiv)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_hivmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_hivmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_hivmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_hivmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_hivmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_hivmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_hivmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_hivmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Diabetes)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_dmmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_dmmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_dmmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_dmmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_dmmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_dmmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_dmmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_dmmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Medication Adherence (Hypertension)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_htnmedicationadherence
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_htnmedicationadherence
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Visual Score**

**3.0.** Visual score

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**4.0.** <B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *%*
- db_table: intecomm_subject_htnmedicationadherence
- column: visual_score_confirmed
- type: IntegerField
---

**Section: Missed Medications**

**5.0.** When was the last time you missed your study pill?
- db_table: intecomm_subject_htnmedicationadherence
- column: last_missed_pill
- type: CharField
- length: 25
- responses:
  - `today`: *today*
  - `yesterday`: *yesterday*
  - `earlier_this_week`: *earlier this week*
  - `last_week`: *last week*
  - `lt_month_ago`: *less than a month ago*
  - `gt_month_ago`: *more than a month ago*
  - `NEVER`: *have never missed taking my study pills*
---

**6.0.** In the last month, how many days did you miss taking your medication
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_missed_in_days
- type: IntegerField
---

**7.0.** Reasons for missing study pills
- db_table: intecomm_subject_htnmedicationadherence
- column: missed_pill_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `forgot_to_take`: *I simply forgot to take my medication*
  - `travelled`: *I travelled and forgot my medication*
  - `feel_better`: *I felt better and stopped taking my medication*
  - `insufficient_supply`: *I did not get enough medication from hospital/clinic, could not buy more*
  - `feel_ill`: *The medications were making me feel sick*
  - `too_many_pills`: *Too many pills so I stopped / reduced*
  - `OTHER`: *Other, please specify ...*
---

**8.0.** If other, please specify ...
- db_table: intecomm_subject_htnmedicationadherence
- column: other_missed_pill_reason
- type: CharField
- length: 150
- responses: *free text*
---

**9.0.** In the last month, how many days did you NOT HAVE medication to take

&nbsp;&nbsp;&nbsp;&nbsp; *That is, your supply of medication was finished*
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_in_days
- type: IntegerField
---

**10.0.** Reasons for not having medications (supply/shortage)
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason
- type: ManyToManyField
- responses: *Select all that apply*
  - `gov_supply_shortage`: *I did not get enough medication from hospital/clinic*
  - `no_money`: *I did not have money to but my medications*
  - `no_supplier`: *I could not find a supplier with my medications*
  - `N/A`: *Not applicable*
  - `OTHER`: *Other, please specify*
---

**10.1.** If `other` reason for not having medications, specify
- db_table: intecomm_subject_htnmedicationadherence
- column: meds_shortage_reason_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**11.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**12.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_htnmedicationadherence
- column: crf_status_comments
- type: TextField
---


#### Complications: Followup
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_complicationsfollowup
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_complicationsfollowup
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Complications**

**3.0.** Stroke
- db_table: intecomm_subject_complicationsfollowup
- column: stroke
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**4.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: stroke_date
- type: DateField
- format: YYYY-MM-DD
---

**5.0.** Heart attack / heart failure
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: heart_attack_date
- type: DateField
- format: YYYY-MM-DD
---

**7.0.** Renal (kidney) disease
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**8.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: renal_disease_date
- type: DateField
- format: YYYY-MM-DD
---

**9.0.** Vision problems (e.g. blurred vision)
- db_table: intecomm_subject_complicationsfollowup
- column: vision
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**10.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: vision_date
- type: DateField
- format: YYYY-MM-DD
---

**11.0.** Numbness / burning sensation
- db_table: intecomm_subject_complicationsfollowup
- column: numbness
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**12.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: numbness_date
- type: DateField
- format: YYYY-MM-DD
---

**13.0.** Foot ulcers
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** If yes, date

&nbsp;&nbsp;&nbsp;&nbsp; *If exact date not known, see SOP on how to estimate a date.*
- db_table: intecomm_subject_complicationsfollowup
- column: foot_ulcers_date
- type: DateField
- format: YYYY-MM-DD
---

**15.0.** Are there any other major complications to report?
- db_table: intecomm_subject_complicationsfollowup
- column: complications
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**15.1.** complications other

&nbsp;&nbsp;&nbsp;&nbsp; *Please include dates*
- db_table: intecomm_subject_complicationsfollowup
- column: complications_other
- type: TextField
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_complicationsfollowup
- column: crf_status_comments
- type: TextField
---


#### Family History And Knowledge
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_familyhistory
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_familyhistory
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Part 1**

**3.0.** Do you know if anyone else in your household has high blood pressure?
- db_table: intecomm_subject_familyhistory
- column: htn_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**4.0.** Do you know if anyone else in your household has diabetes?
- db_table: intecomm_subject_familyhistory
- column: dm_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**5.0.** Do you know if anyone else in your household has HIV?
- db_table: intecomm_subject_familyhistory
- column: hiv_in_household
- type: CharField
- length: 25
- responses:
  - `No`: *No*
  - `yes_spouse`: *Yes, my spouse*
  - `yes_parents`: *Yes, one of my parents living with me*
  - `yes_relative`: *Yes, another relative living with me*
  - `dont_know`: *Don't know*
---

**Section: Part 2**

**6.0.** High blood pressure and high blood sugar can cause many illnesses like heart attacks, stroke, kidney failure
- db_table: intecomm_subject_familyhistory
- column: high_bp_bs_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**7.0.** Being overweight protects from high blood pressure and high blood sugar
- db_table: intecomm_subject_familyhistory
- column: overweight_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**8.0.** Salty food protects from high blood sugar
- db_table: intecomm_subject_familyhistory
- column: salty_foods_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**9.0.** Regular exercise is important for people with high blood pressure or high blood sugar even if they are taking medicines for these conditions.
- db_table: intecomm_subject_familyhistory
- column: excercise_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**10.0.** Drugs for blood sugar and blood pressure can make you unwell
- db_table: intecomm_subject_familyhistory
- column: take_medicine_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**11.0.** It is best to stop taking blood pressure pills when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_htn_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**12.0.** Herbs and traditional medicine are better for managing blood pressure than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_htn_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**13.0.** It is best to stop taking blood sugar medicines when you feel better and start pill taking again when you feel sick
- db_table: intecomm_subject_familyhistory
- column: stop_dm_meds_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**14.0.** Herbs and traditional medicine are better for managing diabetes than pills and medicines
- db_table: intecomm_subject_familyhistory
- column: traditional_dm_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**15.0.** Having drinks with sugar (e.g. tea/coffee) causes diabetes
- db_table: intecomm_subject_familyhistory
- column: dm_cause_tf
- type: CharField
- length: 25
- responses:
  - `true`: *True*
  - `false`: *False*
  - `dont_know`: *Don't know*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_familyhistory
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_familyhistory
- column: crf_status_comments
- type: TextField
---


#### Overall Quality Of Life (Icecap-A V2)
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_icecapa
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_icecapa
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: About your overall quality of life**

**3.0.** Feeling settled and secure
- db_table: intecomm_subject_icecapa
- column: stability
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to feel settled and secure in <B>all</B> areas of my life*
  - `3`: *I am able to feel settled and secure in <B>many</B> areas of my life*
  - `2`: *I am able to feel settled and secure in a <B>few</B> areas of my life*
  - `1`: *I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life*
---

**4.0.** Love, friendship and support
- db_table: intecomm_subject_icecapa
- column: attachment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of love, friendship and support*
  - `3`: *I can have <B>quite a lot</B> of love, friendship and support*
  - `2`: *I can have <B>a little</B> love, friendship and support*
  - `1`: *I <B>cannot</B> have <B>any</B> love, friendship and support*
---

**5.0.** Being independent
- db_table: intecomm_subject_icecapa
- column: autonomy
- type: CharField
- length: 5
- responses:
  - `4`: *I am able to be <B>completely</B> independent*
  - `3`: *I am able to be independent in <B>many</B> things*
  - `2`: *I am able to be independent in <B>a few</B> things*
  - `1`: *I am <B>unable</B> to be at all independent*
---

**6.0.** Achievement and progress
- db_table: intecomm_subject_icecapa
- column: achievement
- type: CharField
- length: 5
- responses:
  - `4`: *I can achieve and progress in <B>all</B> aspects of my life*
  - `3`: *I can achieve and progress in <B>many</B> aspects of my life*
  - `2`: *I can achieve and progress in <B>a few</B> aspects of my life*
  - `1`: *I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life*
---

**7.0.** Enjoyment and pleasure
- db_table: intecomm_subject_icecapa
- column: enjoyment
- type: CharField
- length: 5
- responses:
  - `4`: *I can have <B>a lot</B> of enjoyment and pleasure*
  - `3`: *I can have <B>quite a lot</B> of enjoyment and pleasure*
  - `2`: *I can have <B>a little</B> enjoyment and pleasure*
  - `1`: *I <B>cannot</B> have <B>any</B> enjoyment and pleasure*
---


#### Euroqol Eq-5D-3L Instrument
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_eq5d3l
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_eq5d3l
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Describe your health TODAY ...**

**3.0.** Mobility
- db_table: intecomm_subject_eq5d3l
- column: mobility
- type: CharField
- length: 45
- responses:
  - `no_problems_in_walking`: *I have no problems in walking about*
  - `some_problems_in_walking`: *I have some problems in walking about*
  - `confined_to_bed`: *I am confined to bed*
---

**4.0.** Self-care
- db_table: intecomm_subject_eq5d3l
- column: self_care
- type: CharField
- length: 45
- responses:
  - `no_problems_with_self_care`: *I have no problems with self-care*
  - `problems_washing_dressing_myself`: *I have some problems washing or dressing myself*
  - `unable_to_wash_dress_myself`: *I am unable to wash or dress myself*
---

**5.0.** Usual activities

&nbsp;&nbsp;&nbsp;&nbsp; *Example. work, study, housework, family or leisure activities*
- db_table: intecomm_subject_eq5d3l
- column: usual_activities
- type: CharField
- length: 45
- responses:
  - `no_problems_performing_usual_activities`: *I have no problems with performing my usual activities*
  - `some_problems_performing_usual_activities`: *I have some problems with performing my usual activities*
  - `unable_to_perform_usual_activities`: *I am unable to perform my usual activities*
---

**6.0.** Pain / Discomfort
- db_table: intecomm_subject_eq5d3l
- column: pain_discomfort
- type: CharField
- length: 45
- responses:
  - `no_pain_discomfort`: *I have no pain or discomfort*
  - `moderate_pain_discomfort`: *I have moderate pain or discomfort*
  - `extreme_pain_discomfort`: *I have extreme pain or discomfort*
---

**7.0.** Anxiety / Depression
- db_table: intecomm_subject_eq5d3l
- column: anxiety_depression
- type: CharField
- length: 45
- responses:
  - `not_anxious_depressed`: *I am not anxious or depressed*
  - `moderately_anxious_depressed`: *I am moderately anxious or depressed*
  - `extremely_anxious_depressed`: *I am extremely anxious or depressed*
---

**Section: How is your health TODAY?**

**8.0.** Visual score for how your health is TODAY
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_slider
- type: CharField
- length: 3
- responses: *free text*
---

**9.0.** <B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.

&nbsp;&nbsp;&nbsp;&nbsp; *This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.*
- db_table: intecomm_subject_eq5d3l
- column: health_today_score_confirmed
- type: IntegerField
---


#### Health Economics: Household Head
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><p>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household members**

**3.0.** What is the total number of people who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_count
- type: IntegerField
---

**4.0.** What is the total number of people 14 years or under who live in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Persons*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hh_minors_count
- type: IntegerField
---

**Section: Household head: Gender and age**

**5.0.** Are you the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *If YES, STOP and save the form.*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**6.0.** Is the household head female or male?
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_gender
- type: CharField
- length: 15
- responses:
  - `M`: *Male*
  - `F`: *Female*
  - `N/A`: *Not applicable*
---

**7.0.** How old is the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *In years as of today*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_age
- type: IntegerField
---

**Section: Head of household**

**8.0.** What is your relationship to the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh
- type: CharField
- length: 25
- responses:
  - `WIFE_HUSBAND`: *Wife/Husband*
  - `SON_DAUGHTER`: *Son/Daughter*
  - `SON_DAUGHTERINLAW`: *Son/Daughter-in-law*
  - `GRANDCHILD`: *Grandchild*
  - `PARENT`: *Parent*
  - `PARENTINLAW`: *Parent-in-law*
  - `BROTHER_SISTER`: *Brother/Sister*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER relationship, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: relationship_to_hoh_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Religion**

**9.0.** How would you describe the household head’s religious orientation?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion
- type: ForeignKey
---

**9.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Ethnicity**

**10.0.** What is the household head’s ethnic background?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity
- type: ForeignKey
---

**10.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Education**

**11.0.** Highest level of education completed by the household head?

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education
- type: ForeignKey
---

**11.1.** If OTHER education, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Employment**

**12.0.** Household head’s employment status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**13.0.** Household head’s type of employment

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type
- type: ForeignKey
---

**13.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**Section: Head of household: Marital status**

**14.0.** Household head’s marital status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**14.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Head of household: Insurance**

**15.0.** Household head’s health insurance and ‘club’ status

&nbsp;&nbsp;&nbsp;&nbsp; *Not applicable if patient is head of household*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**15.1.** If OTHER, specify ...
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: hoh_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**16.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**17.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicshouseholdhead
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Patient
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicspatient
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicspatient
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Patient characteristics**

**3.0.** How would you describe your religious orientation?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion
- type: ForeignKey
---

**3.1.** If OTHER religious orientation, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_religion_other
- type: CharField
- length: 35
- responses: *free text*
---

**4.0.** What is your ethnic background?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity
- type: ForeignKey
---

**4.1.** If OTHER ethnic background, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_ethnicity_other
- type: CharField
- length: 35
- responses: *free text*
---

**5.0.** Highest level of education completed?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education
- type: ForeignKey
---

**5.1.** If OTHER level of education, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_education_other
- type: CharField
- length: 35
- responses: *free text*
---

**6.0.** What is your employment status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_status
- type: CharField
- length: 25
- responses:
  - `1`: *Full time employed*
  - `2`: *Regular part time employed *
  - `9`: *Self employed *
  - `3`: *Irregular/ occasional/ day worker employment*
  - `4`: *Non-paid/ voluntary role *
  - `5`: *Student*
  - `6`: *Homemaker*
  - `7`: *Unemployed (able to work)*
  - `8`: *Unemployed (unable to work)*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**7.0.** What is your type of employment?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type
- type: ForeignKey
---

**7.1.** If OTHER type of employment, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_employment_type_other
- type: CharField
- length: 100
- responses: *free text*
---

**8.0.** What is your marital status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status
- type: CharField
- length: 25
- responses:
  - `1`: *Never Married (but not co-habiting)*
  - `2`: *Co-habiting*
  - `3`: *Currently Married*
  - `4`: *Separated/Divorced*
  - `5`: *Widowed*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
  - `N/A`: *Not applicable*
---

**8.1.** If OTHER marital status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_marital_status_other
- type: CharField
- length: 35
- responses: *free text*
---

**9.0.** What is your health insurance status?
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance
- type: ManyToManyField
- responses: *Select all that apply*
  - `private`: *Private/work-place/voluntary health insurance*
  - `nhif`: *NHIF (National Health Insurance Fund)*
  - `chf`: *CHF (Community Health Insurance Fund)*
  - `community`: *Community-based health insurance*
  - `club`: *Patient support group / club*
  - `none`: *None*
  - `dont_know`: *Don’t know*
  - `OTHER`: *Other, specify*
  - `N/A`: *Not applicable*
---

**9.1.** If OTHER health insurance status, specify ...
- db_table: intecomm_subject_healtheconomicspatient
- column: pat_insurance_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicspatient
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Assets
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsassets
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsassets
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Household assets**

**3.0.** Is the house you live in rented, owned by you (either on your own, or with someone else), or owned by someone else in your family?
- db_table: intecomm_subject_healtheconomicsassets
- column: residence_ownership
- type: CharField
- length: 25
- responses:
  - `renter`: *Rent*
  - `owner`: *Own themselves*
  - `family_owned`: *Owned by someone else in family*
  - `nonfamily_owned`: *Owned by someone else other than family member*
  - `joint_owned`: *Owned together with someone*
---

**4.0.** If the owner [you] were to sell this dwelling today, do you know the approximate value?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value_known
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** About how much is it worth?

&nbsp;&nbsp;&nbsp;&nbsp; *in local currency*
- db_table: intecomm_subject_healtheconomicsassets
- column: dwelling_value
- type: IntegerField
---

**6.0.** How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?
- db_table: intecomm_subject_healtheconomicsassets
- column: rooms
- type: IntegerField
---

**7.0.** How many rooms are used for sleeping in your dwelling?
- db_table: intecomm_subject_healtheconomicsassets
- column: bedrooms
- type: IntegerField
---

**8.0.** How many beds does your dwelling have in total?
- db_table: intecomm_subject_healtheconomicsassets
- column: beds
- type: IntegerField
---

**9.0.** What is the major construction material of the roof?
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Tin*
  - `4`: *Wood*
  - `5`: *Iron sheet*
  - `6`: *Tiles *
  - `7`: *Cement*
  - `OTHER`: *Other, specify ...*
---

**9.1.** If OTHER roof material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: roof_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**10.0.** What is the major construction material of the external wall?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material
- type: CharField
- length: 25
- responses:
  - `1`: *Thatch, Straw*
  - `2`: *Mud and poles*
  - `3`: *Timber*
  - `OPTION_RETIRED`: *Un-burnt bricks*
  - `5`: *Bricks with mud*
  - `6`: *Bricks with cement*
  - `7`: *Cement blocks*
  - `8`: *Stone*
  - `OTHER`: *Other, specify ...*
---

**10.1.** If OTHER external wall material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_wall_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**11.0.** What is the main material on external windows?
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material
- type: CharField
- length: 25
- responses:
  - `1`: *Glass*
  - `2`: *Bags*
  - `3`: *Wood*
  - `4`: *Iron/metal*
  - `5`: *Screens*
  - `6`: *No windows*
  - `OTHER`: *Other, specify ...*
---

**11.1.** If OTHER external window material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: external_window_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**12.0.** What is the major construction material of the floor?

&nbsp;&nbsp;&nbsp;&nbsp; *If there are similar amounts of more than one type of flooring, select the multiple types that apply. Otherwise select the main type of flooring*
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material
- type: CharField
- length: 25
- responses:
  - `6`: *Earth, sand*
  - `7`: *Dung, wood, planks, palm, bamboo*
  - `8`: *Parquet, polished wood, vinyl, asphalt strips*
  - `9`: *Ceramic tiles*
  - `10`: *Cement*
  - `11`: *Carpet*
  - `OTHER`: *Other, specify ...*
---

**12.1.** If OTHER floor material, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: floor_material_other
- type: CharField
- length: 35
- responses: *free text*
---

**13.0.** Does your household have electricity?
- db_table: intecomm_subject_healtheconomicsassets
- column: electricity
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**14.0.** What is the main source of lighting?
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *Paraffin, kerosene or gas lantern *
  - `3`: *Firewood*
  - `4`: *Candle*
  - `OTHER`: *Other, specify ...*
---

**14.1.** If OTHER lighting source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: lighting_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**15.0.** What type of fuel do you primarily use for cooking?
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel
- type: CharField
- length: 25
- responses:
  - `1`: *Electricity*
  - `2`: *LPG/natural gas/biogas*
  - `3`: *Kerosene*
  - `4`: *Charcoal*
  - `5`: *Wood*
  - `6`: *Coal/lignite, straw/shrubs/grass. agricultural crop, animal dung*
  - `7`: *No food cooked in the household*
  - `OTHER`: *Other, specify ...*
---

**15.1.** If OTHER cooking fuel, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: cooking_fuel_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Drinking water and sanitation**

**16.0.** What is the main source of drinking water for the household?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source
- type: CharField
- length: 25
- responses:
  - `piped_into_plot`: *Piped into dwelling/yard plot*
  - `piped_to_neighbour`: *Piped to neighbour*
  - `standpipe`: *Public tap/standpipe*
  - `borehole`: *Tube well or borehole*
  - `protected_well`: *Protected dug well*
  - `protected_spring`: *Protected spring*
  - `rainwater`: *Rainwater*
  - `bottled_water_improved`: *Bottled water, improved source for cooking/hand washing (1-7)*
  - `unprotected_well`: *Unprotected dug well*
  - `unprotected_spring`: *Unprotected spring*
  - `tanker`: *Tanker truck/cart with small tank*
  - `surface_water`: *Surface water (river etc.)*
  - `bottled_water_unimproved`: *Bottle water, unimproved source for cooking/hand washing (9-12)*
  - `OTHER`: *Other, specify ...*
---

**16.1.** If OTHER water source, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: water_source_other
- type: CharField
- length: 35
- responses: *free text*
---

**17.0.** How long does it take to obtain drinking water?
- db_table: intecomm_subject_healtheconomicsassets
- column: water_obtain_time
- type: CharField
- length: 25
- responses:
  - `on_premises`: *Water on premises (includes water piped to a neighbour)*
  - `less_30min`: *Less than 30 minutes*
  - `greater_30min`: *30 minutes or longer*
  - `dont_know`: *Don't know*
---

**18.0.** What type of toilet is mainly used in your household?

&nbsp;&nbsp;&nbsp;&nbsp; *Note: 'private' (1-7) is a toilet solely used by the household and 'shared' (8-14) is a toilet shared by two or more households.*
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet
- type: CharField
- length: 25
- responses:
  - `1`: *1. Flush/pour flush to piped sewer system – private*
  - `2`: *2. Flush/pour flush to septic tank – private *
  - `3`: *3. Flush/pour flush to pit latrine – private*
  - `4`: *4. Ventilated improved pit (VIP) latrine – private *
  - `5`: *5. Pit latrine with slab – private*
  - `6`: *6. Composting toilet – private*
  - `7`: *7. EcoSan – private*
  - `8`: *8. Flush/pour flush to piped sewer system – shared*
  - `9`: *9. Flush/pour flush to septic tank – shared*
  - `10`: *10. Flush/pour flush to pit latrine – shared*
  - `11`: *11. Ventilated improved pit (VIP) latrine – shared*
  - `12`: *12. Pit latrine with slab – shared*
  - `13`: *13. Composting toilet – shared*
  - `14`: *14. EcoSan – shared*
  - `15`: *15. Flush/pour flush not to sewer/septic tank/pit latrine*
  - `16`: *16. Pit latrine with slab (non-washable)*
  - `17`: *17. Pit latrine without slab/open pit*
  - `18`: *18. Bucket*
  - `19`: *19. Hanging toilet/hanging latrine*
  - `20`: *20. Open defecation (no facility/bush/field)*
  - `OTHER`: *Other, specify ...*
---

**18.1.** If OTHER type of toilet, specify
- db_table: intecomm_subject_healtheconomicsassets
- column: toilet_other
- type: CharField
- length: 35
- responses: *free text*
---

**Section: Household assets (continued)**

**19.0.** Radio
- db_table: intecomm_subject_healtheconomicsassets
- column: radio
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**20.0.** Television
- db_table: intecomm_subject_healtheconomicsassets
- column: television
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**21.0.** Mobile phone
- db_table: intecomm_subject_healtheconomicsassets
- column: mobile_phone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**22.0.** Computer
- db_table: intecomm_subject_healtheconomicsassets
- column: computer
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**23.0.** Non-mobile telephone
- db_table: intecomm_subject_healtheconomicsassets
- column: telephone
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**24.0.** Fridge
- db_table: intecomm_subject_healtheconomicsassets
- column: fridge
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**25.0.** Generator
- db_table: intecomm_subject_healtheconomicsassets
- column: generator
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**26.0.** Flat iron
- db_table: intecomm_subject_healtheconomicsassets
- column: iron
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**27.0.** Bicycle
- db_table: intecomm_subject_healtheconomicsassets
- column: bicycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**28.0.** Motorcycle/scooter (PikiPiki/Boda Boda)
- db_table: intecomm_subject_healtheconomicsassets
- column: motorcycle
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**29.0.** Dala Dala
- db_table: intecomm_subject_healtheconomicsassets
- column: dala_dala
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**30.0.** Car
- db_table: intecomm_subject_healtheconomicsassets
- column: car
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**31.0.** Boat with a motor
- db_table: intecomm_subject_healtheconomicsassets
- column: motorboat
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**32.0.** Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)
- db_table: intecomm_subject_healtheconomicsassets
- column: large_livestock
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**33.0.** Small animals (goats, sheep, chickens or other poultry, etc)
- db_table: intecomm_subject_healtheconomicsassets
- column: small_animals
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**34.0.** A business or shop
- db_table: intecomm_subject_healtheconomicsassets
- column: shop
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
---

**Section: CRF status**

**35.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**36.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsassets
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Property
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsproperty
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsproperty
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Property**

**3.0.** Do you own any land.
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_owner
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_value
- type: IntegerField
---

**5.0.** Surface area
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area
- type: DecimalField
---

**6.0.** Surface area (units)
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_surface_area_units
- type: CharField
- length: 15
- responses:
  - `hectares`: *hectares*
  - `acres`: *acres*
  - `decimals`: *decimals (1 decimal = hundredth of an acre)*
  - `sq_feet`: *sq. feet (length * width)*
  - `sq_meters`: *sq. meters (length * width)*
  - `N/A`: *Not applicable*
---

**7.0.** Do you own any other property other than your primary dwelling?
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**8.0.** About how much is this worth in total?

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsproperty
- column: land_additional_value
- type: IntegerField
---

**Section: Calculated values**

**9.0.** calculated land surface area

&nbsp;&nbsp;&nbsp;&nbsp; *m2 (system calculated)*
- db_table: intecomm_subject_healtheconomicsproperty
- column: calculated_land_surface_area
- type: DecimalField
---

**Section: CRF status**

**10.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**11.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsproperty
- column: crf_status_comments
- type: TextField
---


#### Health Economics: Income
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.

*Additional instructions*: <H5><B><font color='orange'>Interviewer to read</font></B></H5><P>We want to learn about the household and we use these questions to get an understanding of wealth and opportunities in the community.</P><p>Now, I will ask about <b>income for the household</b> from paid work or other sources.</p><p>I know it may be difficult to calculate those figures, but please do try to give amounts as accurately as possible. Remember that <b>all information will be kept strictly confidential</b>. This information is important to assess overall health and well-being of people in your household, compared to other similar households.</p><p>I am now going to read you a list of possible sources of income. Thinking over the last 12 months, can you tell me what the average earnings of the household have been per week or per month or per year? Please tell me whichever time period that is easier for you.</p>


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_healtheconomicsincome
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_healtheconomicsincome
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Wages / Salary**

**3.0.** Income from wages, salary from job
- db_table: intecomm_subject_healtheconomicsincome
- column: wages
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**4.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**5.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: wages_value
- type: IntegerField
---

**Section: Selling, trading or hawking**

**6.0.** Earnings from selling, trading or hawking products?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**7.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**8.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: selling_value
- type: IntegerField
---

**Section: Rental income**

**9.0.** Income from rental of property?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**10.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**11.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: rental_income_value
- type: IntegerField
---

**Section: Pension, etc.**

**12.0.** State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?

&nbsp;&nbsp;&nbsp;&nbsp; *Pensions by work*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**13.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**14.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: pension_value
- type: IntegerField
---

**Section: NGO assistance**

**15.0.** Assistance from nongovernmental organization
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**16.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**17.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: ngo_assistance_value
- type: IntegerField
---

**Section: Interest and dividends**

**18.0.** Interest, dividends

&nbsp;&nbsp;&nbsp;&nbsp; *(for example, from savings account or fixed deposits)?*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**19.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**20.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: interest_value
- type: IntegerField
---

**Section: Money transfers (domestic)**

**21.0.** Money transfers from family members or friends residing inside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**22.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**23.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: internal_remit_value
- type: IntegerField
---

**Section: Remittances (from outside the country)**

**24.0.** Money transfers from family members or friends residing outside the country
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**25.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**26.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_value
- type: IntegerField
---

**27.0.** In what currency do you receive remittances?
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency
- type: CharField
- length: 50
- responses:
  - `USD`: *USD*
  - `GBP`: *GBP*
  - `OTHER`: *Other, specify ...*
  - `dont_know`: *Don't know*
---

**27.1.** If OTHER currency, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: external_remit_currency_other
- type: CharField
- length: 50
- responses: *free text*
---

**Section: Other sources of income**

**28.0.** Do you have additional sources of income not included above?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**28.1.** If YES additional sources, specify ...
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_other
- type: CharField
- length: 50
- responses: *free text*
---

**29.0.** Over which <u>time period</u> are you able to estimate?
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value_known
- type: CharField
- length: 15
- responses:
  - `weekly`: *as weekly income*
  - `monthly`: *as monthly income*
  - `yearly`: *as yearly income*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
  - `N/A`: *Not applicable*
---

**30.0.** Estimated <u>total amount of income</u> from this source over the time period from above

&nbsp;&nbsp;&nbsp;&nbsp; *Use cash equivalent in local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: more_sources_value
- type: IntegerField
---

**Section: Dependents, financial status**

**31.0.** Outside of this household, how many other people depend on this household’s income?

&nbsp;&nbsp;&nbsp;&nbsp; *Insert '0' if no dependents other than the members in the household roster*
- db_table: intecomm_subject_healtheconomicsincome
- column: external_dependents
- type: IntegerField
---

**32.0.** Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?
- db_table: intecomm_subject_healtheconomicsincome
- column: income_enough
- type: CharField
- length: 15
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `Dont_know`: *Don't know*
---

**33.0.** Would you say your household's financial situation is?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status
- type: CharField
- length: 25
- responses:
  - `1`: *Very good*
  - `2`: *Good*
  - `3`: *Moderate*
  - `4`: *Bad*
  - `5`: *Very bad*
  - `DWTA`: *Don't want to answer*
---

**34.0.** How would you rate your household’s financial situation compared with others in your community?
- db_table: intecomm_subject_healtheconomicsincome
- column: financial_status_compare
- type: CharField
- length: 25
- responses:
  - `1`: *Among most wealthy*
  - `2`: *Above average *
  - `3`: *Average wealth*
  - `4`: *Below average*
  - `5`: *Among least wealthy*
  - `DWTA`: *Don't want to answer*
---

**Section: Debt / Loans**

**35.0.** Does your household or any members of the household have current debt or outstanding loans?
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt
- type: CharField
- length: 25
- responses:
  - `Yes`: *Yes*
  - `No`: *No*
  - `dont_know`: *Don't know*
  - `DWTA`: *Don't want to answer*
---

**36.0.** What is the approximate total amount of this debt or loan(s)?

&nbsp;&nbsp;&nbsp;&nbsp; *In local currency*
- db_table: intecomm_subject_healtheconomicsincome
- column: household_debt_value
- type: IntegerField
---

**Section: CRF status**

**37.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**38.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_healtheconomicsincome
- column: crf_status_comments
- type: TextField
---


#### Next Appointment
*[missing model class docstring]*


*Instructions*: Please complete the form below. Required questions are in bold. When all required questions are complete click SAVE or, if available, SAVE NEXT. Based on your responses, additional questions may be required or some answers may need to be corrected.


**Section: Main**

**1.0.** subject visit
- db_table: intecomm_subject_nextappointment
- column: subject_visit
- type: OneToOneField
---

**2.0.** Report Date

&nbsp;&nbsp;&nbsp;&nbsp; *If reporting today, use today's date/time, otherwise use the date/time this information was reported.*
- db_table: intecomm_subject_nextappointment
- column: report_datetime
- type: DateTimeField
- format: YYYY-MM-DD HH:MM:SS.sss (tz=UTC)
---

**Section: Integrated Clinic**

**3.0.** What is the source of this appointment date
- db_table: intecomm_subject_nextappointment
- column: info_source
- type: ForeignKey
- length: 15
---

**4.0.** health facility
- db_table: intecomm_subject_nextappointment
- column: health_facility
- type: ForeignKey
---

**5.0.** Next scheduled routine/facility appointment

&nbsp;&nbsp;&nbsp;&nbsp; *Should fall on an Integrated clinic day*
- db_table: intecomm_subject_nextappointment
- column: appt_date
- type: DateField
- format: YYYY-MM-DD
---

**6.0.** Override date check?

&nbsp;&nbsp;&nbsp;&nbsp; *Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.*
- db_table: intecomm_subject_nextappointment
- column: allow_create_interim
- type: BooleanField
---

**7.0.** Which study visit code is closest to this appointment date

&nbsp;&nbsp;&nbsp;&nbsp; *Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.*
- db_table: intecomm_subject_nextappointment
- column: visitschedule
- type: ForeignKey
- length: 15
---

**Section: CRF status**

**8.0.** CRF status

&nbsp;&nbsp;&nbsp;&nbsp; *If some data is still pending, flag this CRF as incomplete*
- db_table: intecomm_subject_nextappointment
- column: crf_status
- type: CharField
- length: 25
- responses:
  - `INCOMPLETE`: *Incomplete (some data pending)*
  - `COMPLETE`: *Complete*
---

**9.0.** Any comments related to status of this CRF

&nbsp;&nbsp;&nbsp;&nbsp; *for example, why some data is still pending*
- db_table: intecomm_subject_nextappointment
- column: crf_status_comments
- type: TextField
---


#### Requisitions



*Rendered on 2024-01-30 08:39*


